#!/usr/bin/perl
# $Id: check_pool.pl,v 1.1 2001/08/24 00:26:35 jcheng Exp $
# Copyright 2000, 2001 Sun Microsystems, Inc., All rights reserved.
#
# Description:
#	Runs on Network creation, or change of Network.ipaddr property.
#       If IP pooling enabled, checks that the given IP address is
#       within the pool of acceptable IPs.

use lib qw(/usr/sausalito/perl);
use lib qw(/usr/sausalito/handlers/base/network);
use CCE;
use IpPooling;

# FIXME. Passing in i18n domain, needed to proper I18n msgs
# and variable interpolation by cce client libs.
my $cce = new CCE('Domain' => 'base-network');

$cce->connectfd();

my $network_new = $cce->event_new();

my ($sysoid) = $cce->find('System');
my ($ok, $network) = $cce->get($sysoid, 'Network');
if (!$ok) {
    $cce->bye('FAIL');
    exit 1;
}

if ($network->{pooling} && $network_new->{ipaddr}) {
    my (@oids) = $cce->find('IPPoolingRange');
    my @ranges = ();

    # get ranges
    foreach $a_oid (@oids) {
	my ($ok, $range) = $cce->get($a_oid);
	if (!$ok) {
	    $cce->bye('FAIL');
	    exit 1;
	}
	push @ranges, $range;
    }
    
    my (@error_ips) = IpPooling::validate_pooling_state(\@ranges, [ $network_new->{ipaddr} ]);
    if (@error_ips) {
	$cce->warn('ip_restricted', {'ipaddr' => $network_new->{ipaddr}});
	$cce->bye('FAIL');
	exit 1;
    }
}

$cce->bye('SUCCESS');
exit 0;
