#!/usr/bin/perl -I/usr/sausalito/perl -I/usr/sausalito/handlers/base/network
# $Id: destroy_range.pl,v 1.1 2001/08/24 00:26:35 jcheng Exp $
# Copyright 2000, 2001 Sun Microsystems, Inc., All rights reserved.
# If pooling is enabled, see if we can delete this range.
# If after deleting this range, all the ranges still encompass all the ips,
# then we can delete this. Otherwise, we're not allowed to delete this.

use CCE;
use IpPooling;

my $cce = new CCE('Domain' => 'base-network');
$cce->connectfd();

my $old = $cce->event_old();
my $object = $cce->event_object();
my $new = $cce->event_new();

my ($sysoid) = $cce->findx('System');
my ($ok, $network) = $cce->get($sysoid, 'Network');

# check against network interfaces if pooling is enabled
if ($network->{pooling}) {
    
    my (@oids) = $cce->find('IPPoolingRange');
    my @ranges = ();
    
    # we know we're being deleted
    # so get all the OTHER ranges
    foreach $a_oid (@oids) {
	if ($a_oid != $object->{event_oid}) {
	    my ($ok, $range) = $cce->get($a_oid);
	    if (!$ok) {
		$cce->bye('FAIL');
		exit 1;
	    }
	    push @ranges, $range;;
	}
    }
    
    # get network ips
    my (@network_oids) = $cce->find('Network', { 'enabled' => 1});
    foreach my $oid (@network_oids) {
	my ($ok, $net) = $cce->get($oid);
	if (!$ok) {
	    $cce->bye('FAIL');
	    exit 1;
	}
	push @ips, $net->{ipaddr};
    }


    my (@error_ips) = IpPooling::validate_pooling_state(\@ranges, \@ips);
    if (@error_ips) {
	$cce->warn('cant_delete_range', { 'affected_ips' => join(',', @error_ips)});
	$cce->bye('FAIL');
	exit 1;
    }
}

$cce->bye('SUCCESS');
exit 0;

    
