#!/usr/bin/perl -w -I/usr/sausalito/perl
# $Id: dns.pl,v 1.4 2001/07/22 06:26:58 pbaltz Exp $
# Copyright 2000, 2001 Sun Microsystems, Inc., All rights reserved.
#
# dns.pl
# This handler make sure that the Qube has at least one DNS server
# specified if it is connected to the internet in any way.  This
# is mostly for the case when the network is auto-configured at
# first boot.  This helps users who may not be aware of the need
# for a DNS server to use the Qube as a router.

use CCE;

my $cce = new CCE;

$cce->connectfd();

my $system = $cce->event_object();
my ($ok, $sysnet) = $cce->get($cce->event_oid(), 'Network');

if (not $ok) 
{
    $cce->warn('[[base-network.cantGetNetwork]]');
    $cce->bye('FAIL');
    exit(1);
}

# if the internetMode is anything other than none, make sure
# there is a DNS server specified.  If there isn't, make the
# Qube its own DNS server.
if ($sysnet->{internetMode} ne 'none') 
{
    # check to make sure we have at least one dns server specified
    my @dns_servers = $cce->scalar_to_array($system->{dns});

    if (scalar(@dns_servers) > 0) 
    {
        # already have dns servers specified
        $cce->bye('SUCCESS');
        exit(0);
    }

    # other wise, there is currently no DNS server specified
    # insert local host as dns server
    ($ok) = $cce->set($cce->event_oid(), '', { 'dns' => '&127.0.0.1&' });
    
    if (not $ok) 
    {
        $cce->warn('[[base-network.couldntChangeDns]]');
        $cce->bye('FAIL');
        exit(1);
    }

    # start the DNS server
    ($ok) = $cce->set($cce->event_oid(), 'DNS', { 'enabled' => 1 });

    if (not $ok) 
    {
        $cce->warn('[[base-network.couldntStartDns]]');
        $cce->bye('FAIL');
        exit(1);
    }
}

$cce->bye('SUCCESS');
exit(0);
