#!/usr/bin/perl -w -I/usr/sausalito/perl
# $Id: no_duplicates.pl,v 1.5 2001/12/04 07:25:08 pbaltz Exp $
# Copyright 2001 Sun Microsystems, Inc.  All rights reserved.
#
# don't allow the creation of Network aliases with the same IP address
# as another alias or a real interface.  Also don't allow a real interface
# to have it's IP address changed to that of another real interface.

use CCE;

my $cce = new CCE('Domain' => 'base-network');
$cce->connectfd();

my $new_net = $cce->event_object();

# make sure the device is unique
my @devices = $cce->find('Network', { 'device' => $new_net->{device} });

# there should be only the current object found above
if (scalar(@devices) > 1)
{
	$cce->bye('FAIL', 'noDuplicateDevices', { 'device' => $new_net->{device} });
	exit(1);
}

# do things differently if this is real or an alias
my $real = 0;
if ($new_net->{device} =~ /^eth\d$/)
{
    $real = 1;
}

my @old_nets = $cce->find('Network', 
			  { 
			      'ipaddr' => $new_net->{ipaddr},
			      'enabled' => 1
			      });

# look for just real interfaces, in case the interface being modified is real
my @real_nets = $cce->find('Network',
                        {
                            'ipaddr' => $new_net->{ipaddr},
                            'enabled' => 1,
                            'real' => 1
                        });

# only bother if it's enabled and it has a real ip address assigned
if ($new_net->{enabled} && ($new_net->{ipaddr} ne '') && 
	($new_net->{ipaddr} ne '0.0.0.0'))
{

    # fail if it's an alias and a Network object exists with the same IP
    # also fail if it's real and another real interface already has this IP
    if (((scalar(@old_nets) > 1) && !$real) || 
        ((scalar(@real_nets) > 1) && $real))

    {
        $cce->bye('FAIL', 'noDuplicateIPsAllowed', 
                            { 'ipaddr' => $new_net->{ipaddr} });
        exit(1);
    }
} # end if enabled with a valid ip address

# otherwise, it is okay
$cce->bye('SUCCESS');
exit(0);
