#!/usr/bin/perl -I /usr/sausalito/perl
#
# $Id: validate_netmask.pl,v 1.4 2002/05/06 23:50:33 pmartin Exp $
# Copyright 2002 Sun Microsystems, Inc.  All rights reserved.
#
# make sure a netmask is valid (ie leading bits are all 1's and once a 0
# is found all the trailing bits are 0's)
#
# handles both Network.netmask and Route.netmask
#

use CCE;

my $cce = new CCE('Domain' => 'base-network');
$cce->connectfd();

my $network = $cce->event_object();

# if netmask is blank, we have nothing to say
if ($network->{netmask} eq '' || $network->{netmask} eq '0.0.0.0') {
	$cce->bye('SUCCESS');
	exit(0);
}

# setup the error message different for real and alias interfaces
my @pre_error = ();
if (($network->{CLASS} eq 'Network') && $network->{real}) {
	@pre_error = ('invalidNetmaskReal',
		{
			'device' => '[[base-network.interface' .
					$network->{device} . ']]',
			'netmask' => $network->{netmask}
		});
} else {
	# aliases get a generic error message
	@pre_error = ('invalidNetmaskAlias',
		{ 'netmask' => $network->{netmask} });
}

		
my @netmask = split(/\./, $network->{netmask});

# must be at least a subnet of a class A network
if ($netmask[0] != 255) {
	$cce->bye('FAIL', @pre_error);
	exit(1);
}

my $in_zero_part = 0;
for (my $i = 1; $i < scalar(@netmask); $i++) {
	if ($in_zero_part && ($netmask[$i] != 0)) {
		$cce->bye('FAIL', @pre_error);
		exit(1);
	} elsif ($netmask[$i] != 255) {
		if (&is_octet_valid($netmask[$i])) {
			$in_zero_part = 1;
		} else {
			$cce->bye('FAIL', @pre_error);
			exit(1);
		}
	}
}

$cce->bye('SUCCESS');
exit(0);

sub is_octet_valid
{                                                                               
        my $octet = shift;

        # check for edge case
	if ($octet == 0) {
		return 1;
	}

	my $sum = 0;                                                            
        for (my $j = 7; $j >= 0; $j--) {                                        
                $sum += 2 ** $j;                                                 
                if ($octet == $sum) {                                           
                        return 1;                                               
                }                                                               
        }                                                                       
        return 0;                                                               
}
